from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceOnlineEventStreamType, DeviceDetailsSortOrder, DeviceRosState, DeviceDiagnosticsConfiguration, ScopeFilter, DeviceTeleopRosStreamConfigurationMode, DeviceStreamDirectoryWatchConfigurationFileType, DeviceOfflineEventMetadata, RtcInfoRtcIceTransportPoliciesItem, CommandProgress, DeviceState, DeviceRosConfiguration, DeviceTeleopRosStreamConfiguration, DeviceStreamRosLocalizationConfiguration, OnDemandState, DeviceFollower, DeviceTags, DeviceTelemetryConfiguration, DeviceApplicationConfiguration, TeleopJoystickConfiguration, DeviceStreamDirectoryWatchConfigurationType, OnvifDevice, DeviceOfflineEventType, DeviceStreamCustomConfiguration, DeviceReportedConfigurationState, PartialDeviceType, DeviceStreamConfigurationQuality, DeviceDiskConfiguration, TeleopJoystickAxisConfiguration, DeviceStreamFileTailConfiguration, NetworkInfo, DeviceStreamFileTailConfigurationType, NodeInfo, OnDemandPresenceTimeRange, DeviceRealtimeConfiguration, DeviceTeleopCustomStreamConfigurationQuality, DeviceStreamRosTopicConfigurationRosVersion, DeviceConfiguration, OnDemandPresenceStreamItemGroup, DeviceOfflineEventTags, DeviceStreamHardwareConfigurationQuality, DeviceOnlineEventType, AdapterConfiguration, DeviceTeleopRosStreamConfigurationNumericControlVisualization, DeviceConfigurationTemplate, DeviceStreamHardwareConfigurationType, DeviceTeleopRosStreamConfigurationTopicType, OnDemandStreamPresence, DeviceOnlineEvent, DeviceTeleopHardwareStreamConfiguration, DeviceTeleopRosStreamConfigurationRosVersion, DeviceTeleopHardwareStreamConfigurationHardwareType, DeviceStreamHardwareConfiguration, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceTeleopRosStreamConfigurationAudioCodec, TeleopViewConfiguration, PartialDeviceTags, OnDemandPresenceStreamItemGroupDatapointType, DeviceTeleopConfiguration, DeviceDetailsType, DeviceStreamConfiguration, DeviceTeleopHardwareStreamConfigurationQuality, DeviceOfflineEvent, AudioDevice, ValidationConfiguration, DeviceStreamFileTailConfigurationFileFormat, DeviceProvisioningRequest, DeviceStreamHardwareConfigurationHardwareType, DeviceScope, ScopeFilterTypesItem, RosTopic, DeviceDetailsSort, RtcInfo, OsInfo, DeviceConfigurationTemplateTags, DeviceTeleopCustomStreamConfiguration, DeviceStreamRosLocalizationConfigurationType, DeviceOfflineEventSeverity, Device, DeviceOnlineEventMetadata, DeviceDetails, DeviceStreamTransformConfiguration, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, DeviceConfigurationDocument, DeviceCredentials, TeleopJoystickConfigurationPosition, DeviceConfigurationDocumentTags, DeviceTeleopRosStreamConfigurationQuality, OnDemandBuffer, DeviceQueryType, DeviceQuery, DeviceTeleopCustomStreamConfigurationMode, DeviceBlobData, DeviceProvisioning, DeviceResourcesConfiguration, DeviceStreamRosTopicConfiguration, DeviceTeleopHardwareStreamConfigurationMode, VideoDevice, RtcInfoRtcIceServerProtocol, DeviceDetailsTags, DeviceType, DeviceStreamRosTransformTreeConfigurationType, PartialDevice, DeviceStreamRosTransformTreeConfigurationRosVersion, DeviceOfflineEventStreamType, DeviceStreamConfigurationTags, DeviceListResponse, DeviceConfigurationTemplateListResponse, DeviceDetailsSortColumn, DeviceStreamRosLocalizationConfigurationRosVersion, Network, HwInfo, DeviceStreamRosTransformTreeConfiguration, DeviceStreamDirectoryWatchConfiguration, DeviceStreamCustomConfigurationType, DeviceApplicationConfigurationConfigurationMap, DeviceDetailsListResponse, DeviceTeleopCustomStreamConfigurationRtcStreamType, OnDemandBufferBufferType, DeviceOnlineEventTags, TeleopJoystickAxisConfigurationDimension, DeviceStreamRosTopicConfigurationType, DeviceScopeTypesItem, DeviceOnlineEventSeverity, KernelInfo, DevicePortForwardingConfiguration, DeviceStateEnv
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional